@@ -1,6 +1,6 @@
-# Copyright (c) 2008-2017 Martin Becker.  All rights reserved.
-# This package is free software; you can redistribute it and/or modify it
-# under the same terms as Perl itself.
+# Copyright (c) 2008-2019 Martin Becker, Blaubeuren.
+# This package is free software; you can distribute it and/or modify it
+# under the terms of the Artistic License 2.0 (see LICENSE file).
 
 # Utility functions for tests:
 # * conditionally skip tests if required modules are not available
@@ -16,14 +16,13 @@ use warnings;
 use Config;
 use base 'Exporter';
 
-our $VERSION   = '0.008';
+our $VERSION   = '0.011';
 our @EXPORT    = qw(use_or_bail maintainer_only);
 our @EXPORT_OK = qw(
     slurp_or_bail this_perl report_version
     init_comp_check comp_ok
 );
 our %EXPORT_TAGS = (
-    default => \@EXPORT,
     comp    => [qw(init_comp_check comp_ok)],
 );
 
@@ -33,7 +32,7 @@ our $MAX_FILESIZE = 1024 * 1024;
 my $comp_failure  = 'no good reason';
 
 sub _guess_distname {
-    my $distname = undef;
+    my $distname = 'This-Distribution';
     if (open my $rh, '<', 'README') {
         my $headline = <$rh>;
         if (defined $headline && $headline =~ /^\s*(\w+(?:[^\w\s]+\w+)*)\s/) {
@@ -41,9 +40,6 @@ sub _guess_distname {
         }
         close $rh;
     }
-    if (!defined $distname) {
-        $distname = 'This-Distribution';
-    }
     return $distname;
 }
 
